(function($) {
    'use strict';

    var first_date = new Date();
    var last_date;
    var ohbe_check_in = $('.ohbe-check-in');
    var ohbe_check_out = $('.ohbe-check-out');
    var ohbe_arrival = $('.ohbe-arrival');

    if (typeof calendar_data != 'undefined' && calendar_data) {
        first_date = getDateFromIso(calendar_data.first_date);
        last_date = getDateFromIso(calendar_data.last_date);
    }

    ohbe_check_in.datepicker({
        monthNames: dp_args.monthNames,
        monthNamesShort: dp_args.monthNamesShort,
        dayNames: dp_args.dayNames,
        dayNamesShort: dp_args.dayNamesShort,
        dayNamesMin: dp_args.dayNamesMin,
        firstDay: dp_args.firstDay,
        isRTL: dp_args.isRTL,
        dateFormat: 'dd-mm-yy',
        minDate: $.datepicker.formatDate('dd-mm-yy', first_date),
        maxDate: $.datepicker.formatDate('dd-mm-yy', last_date),
        beforeShowDay: mayCheckIn,
        onSelect: onSelectCheckInDate
    });

    ohbe_check_out.datepicker({
        dateFormat: 'dd-mm-yy',
        monthNames: dp_args.monthNames,
        monthNamesShort: dp_args.monthNamesShort,
        dayNames: dp_args.dayNames,
        dayNamesShort: dp_args.dayNamesShort,
        dayNamesMin: dp_args.dayNamesMin,
        firstDay: dp_args.firstDay,
        isRTL: dp_args.isRTL,
        onSelect: onSelectCheckOutDate
    });

    if (search_filters.promotion_code != '') {
        $('.ohbe-promo').val(search_filters.promotion_code);
    }
    if (search_filters.check_in) {
        ohbe_check_in.datepicker('setDate', search_filters.check_in);
    }
    if (search_filters.check_out) {
        ohbe_check_out.datepicker('setDate', search_filters.check_out);
    }

    setCheckOutAvailableRange(ohbe_check_in, ohbe_check_out);
    setNights(ohbe_check_in, ohbe_check_out);

    ohbe_arrival.datepicker({
        monthNames: dp_args.monthNames,
        monthNamesShort: dp_args.monthNamesShort,
        dayNames: dp_args.dayNames,
        dayNamesShort: dp_args.dayNamesShort,
        dayNamesMin: dp_args.dayNamesMin,
        firstDay: dp_args.firstDay,
        isRTL: dp_args.isRTL,
        dateFormat: 'dd-mm-yy',
        minDate: $.datepicker.formatDate('dd-mm-yy', new Date())
    });

    /**
     * Add days to a given date.
     *
     * @param {object} d Date object.
     * @param {int} numdays Number of days to add.
     * @returns {object} The date that is numdays after d.
     */
    function dateAdd(d, numdays) {
        return moment(d).add(numdays, 'days').toDate();
    }

    /**
     * Get the number of days between the first date and the given date.
     *
     * @param {string} date Date string with GMT format.
     * @returns {int} Number of days.
     */
    function getCalendarDataIndex(date) {
        var d = moment(date);
        var fd = moment(first_date);
        return d.diff(fd, 'days');
    }

    /**
     * Return a Date object for the given YYYY-MM-DD string.
     *
     * @param {string} s Date string.
     * @returns {object}
     */
    function getDateFromIso(s) {
        return moment(s, "YYYY-MM-DD").toDate();
    }

    /**
     * Return whether check in date is available or not.
     *
     * @param {string} date Date string with GMT format.
     * @returns {array} Array with boolean value for enable/disable date button.
     * There are three cases:
     *  1. TRUE: Date is available in Calendar Data.
     *  2. FALSE: Date is unavailable in Calendar Data.
     *  3. TRUE: Calendar Data hasn't been defined.
     */
    function mayCheckIn(date) {
        if (typeof calendar_data != 'undefined' && calendar_data) {
            var index = getCalendarDataIndex(date);
            return [calendar_data.dates_info[index] == '1']; // 1, 2
        }

        return [true]; // 3
    }

    /**
     * Trigger when a check in date is selected in the availability search form.
     *
     * @returns {void}
     */
    function onSelectCheckInDate() {
        var check_out_input = $(this).siblings('.ohbe-check-out');
        setCheckOutAvailableRange($(this), check_out_input);
        check_out_input.datepicker(
            'setDate',
            dateAdd($(this).datepicker('getDate'), 1)
        );
        setNights($(this), check_out_input);
    }

    /**
     * Trigger when a check out date is selected in the availability search form.
     *
     * @returns {void}
     */
    function onSelectCheckOutDate() {
        setNights($(this).siblings('.ohbe-check-in'), $(this));
    }

    /**
     * Set the available range of departure date.
     *
     * @param {object} check_in_input Check in input to be set.
     * @param {object} check_out_input Check out input to be set.
     * @returns {void}
     */
    function setCheckOutAvailableRange(check_in_input, check_out_input) {
        if (typeof calendar_data != 'undefined' && calendar_data) {
            var check_in_date = check_in_input.datepicker('getDate');
            check_out_input.datepicker(
                'option',
                'minDate',
                $.datepicker.formatDate(
                    'dd-mm-yy',
                    dateAdd(check_in_date || first_date, 1)
                )
            );
            // Searching of available range starts at min date index, so a check out
            // date can be set when this is not available for check in
            var min_date_index = getCalendarDataIndex(
                check_in_date ? check_in_date : first_date
            );

            var max_date_index = calendar_data.dates_info.length;
            for (var i=min_date_index; i<max_date_index; i++) {
                if (calendar_data.dates_info[i] == '-') {
                    max_date_index = i;
                    break;
                }
            }

            check_out_input.datepicker(
                'option',
                'maxDate',
                $.datepicker.formatDate(
                    'dd-mm-yy',
                    dateAdd(
                        check_in_date || first_date,
                        max_date_index - min_date_index
                    )
                )
            );
        }
    }

    /**
     * Calculate the nights between two dates.
     *
     * @param {string} check_in_input Checkin input date.
     * @param {string} check_out_input Checkout input date.
     * @returns {void}
     */
    function setNights(check_in_input, check_out_input) {
        var to = moment(check_out_input.datepicker('getDate'));
        var from = moment(check_in_input.datepicker('getDate'));
        var nights = to.diff(from, 'days');
        if (nights < 1) {
            nights = 1;
        }
        $('.ohbe-nights-number').html(nights);
        $('.ohbe-nights-name').html(translation.nights);
    }
})(jQuery);
