<?php
defined('ABSPATH') or exit();

/**
 * Redforts Oscar Hotel Booking
 * Reservation complete functions
 *
 * @author Redforts Software S.L.
 * @copyright Copyright (c) 2015 Redforts Software S.L.
 * @link https://redforts.com
 * @since 0.1.1
 */
class OHBE_Reservation_Complete
{
    /**
     * Print item card's attributes.
     *
     * @param  array $item Single item structure.
     * @return void
     */
    public static function printItemCardData($item) {
        printf(
            'data-name="%s" data-id=%s data-max="%s" data-min="%s"'
            . ' data-daily="%s" data-price=%s data-taxes="%s" data-selected=%s',
            htmlspecialchars($item['name']),
            $item['id'],
            $item['max'],
            $item['min'],
            $item['daily'],
            $item['price'],
            $item['excl_taxes'],
            $item['quantity'] > 0 ? true : false
        );
    }

    /**
     * Print item quantity-total block.
     *
     * @param  array $item Item.
     * @param  int $days Number of days.
     * @return void
     */
    public static function printItemQuantityTotalBlock($item, $days) {
        $total_price = 0;
        if ($item['quantity'] > 0) {
            $total_price = $item['price'] * $item['quantity'];
            if ($item['daily']) {
                $total_price *= $days;
            }
        }
        $total_taxes = !is_null($item['excl_taxes'])
            ? sprintf(
                esc_html(__('Total excluding %1$s%% taxes', 'ohbe')),
                $item['excl_taxes']
            )
            : __('Total including taxes', 'ohbe');
        printf(
            '<button type=button class="btn-quantity minus"%s>'
            . '<span class="dashicons dashicons-minus"></span></button>'
            . '<input class=value name=ohbe_quantity value=%s readonly>'
            . '<button type=button class="btn-quantity plus"%s>'
            . '<span class="dashicons dashicons-plus"></span>'
            . '</button><span class=subtotal></span>',
            $item['quantity'] <= $item['min'] ? ' disabled' : '',
            $item['quantity'],
            isset($item['max']) && $item['quantity'] >= $item['max']
                ? ' disabled'
                : ''
        );
        if ($item['daily']) {
            printf(
                '× ' .
                _n('%d day', '%d days', $days, 'ohbe'),
                $days
            );
        }
        echo '<div class=total>'
            . '<div class=ohbe-title>' . $total_taxes . ':</div>'
            . '<div class=value>' . OHBE_Tools::formatPrice($total_price) . '</div>'
            . '</div>';
    }

    /**
     * Print items accordion.
     *
     * @return void
     */
    public static function printItems() {
        $item_cards = '';
        $item_selected_cards = '';
        $total_price = 0;
        $item_list = OHBE_Reservation::getReservationParam('item_list');

        if ($item_list) {
            $item_unselected_cards_count = 1;
            $item_selected_cards_count = 1;
            foreach ($item_list['items'] as $item) {
                if ($item['quantity'] > 0) {
                    // Selected item
                    $item_price = $item['price'] * $item['quantity'];
                    if ($item['daily']) {
                        $item_price *= $item_list['days'];
                    }
                    $total_price += $item_price;
                    ob_start();
                    include(OHBE_PATH . 'includes/templates/views/item_card.php');
                    OHBE_Availability::printClearfix($item_selected_cards_count);
                    $item_selected_cards .= ob_get_clean();
                    $item_selected_cards_count++;
                }
                else {
                    // Unselected item
                    ob_start();
                    include(OHBE_PATH . 'includes/templates/views/item_card.php');
                    OHBE_Availability::printClearfix($item_unselected_cards_count);
                    $item_cards .= ob_get_clean();
                    $item_unselected_cards_count++;
                }
            }
            echo '<div id=ohbe-description-modal class=ohbe-modal>'
                . '<div class=modal-dialog role=document>'
                . '<div class=modal-content>'
                . '<div class=modal-header>'
                . '<span class=close>&times;</span>'
                . '<h4 class=modal-title>' . __('Description', 'ohbe'). '</h4>'
                . '</div>'
                . '<div class=modal-body></div>'
                . '<div class=modal-footer>'
                . '<button type=button class="btn-ohbe btn-primary accept">'
                . __('Close', 'ohbe')
                . '</button>'
                . '</div></div></div></div>';
        }
        if ($item_selected_cards) {
            echo '<div class="ohbe-accordion item-selected-list">'
                . '<div class="alert alert-availability">'
                . '<span>' . __('The extras you already added to your reservation:', 'ohbe') . ' </span>'
                . OHBE_Tools::formatPrice($total_price) . '</div>'
                . '<ul class="item-list row">' . $item_selected_cards . '</ul>'
                . '</div>';
        }
        if ($item_cards) {
            echo '<div class="ohbe-accordion items-list">'
                . '<div class="alert alert-availability"><span>'
                . __('Add one of our interesting product or services', 'ohbe')
                . '</span></div>'
                . '<ul class="item-list row">'
                . $item_cards
                . '</ul></div>';
        }
    }

    /**
     * Print selected accommodation cards.
     * @return void
     */
    public static function printReservationHeader() {
        $params = OHBE_Reservation::getReservationParam();

        echo '<h3 class=ohbe-acco-selected-list-title>';
        if ($params['just_reserved']) {
            echo __('Thanks for your reservation!', 'ohbe');
            OHBE_Reservation::setReservationParam('just_reserved', false);
        }
        else {
            echo __('Your reservation', 'ohbe');
        }
        echo '</h3>';
        printf('<p>'
            . __('Your reservation number is %s.'
                . ' Please keep it for future reference.', 'ohbe')
            . '</p>',
            '<b>' . $params['reserv_id'] . '</b>'
        );
    }

    /**
     * Render item card's image.
     *
     * @param  array $images Item's images.
     * @return string Image's html structure.
     */
    public static function renderItemCardImage($images) {
        if (isset($images[0]['url'])) {
            return '<a class="description modal-button" '
                    . 'role=button data-modal=description-modal>'
                . '<div class=image>'
                . '<img src="' . $images[0]['url'] . '"></div>'
                . '</a>';
        }
    }

    /**
     * Render item card's name.
     *
     * @param  array $item Item.
     * @return string Name's html structure.
     */
    public static function renderItemCardName($item) {
        if ($item['description'] || count($item['images']) > 0) {
            return sprintf(
                '<a class="description modal-button" '
                . 'role=button data-modal=description-modal title=%s>'
                . '%s<span class="dashicons dashicons-info"></span>'
                . '</a>',
                __('Description', 'ohbe'),
                htmlspecialchars($item['name'])
            );
        }

        return htmlspecialchars($item['name']);
    }

    /**
     * Render item price.
     *
     * @param  array $item Item.
     * @return string Price block's html structure.
     */
    public static function printPrice($item) {
        $html = sprintf(
            '<div class=price><div class=ohbe-title>%s:</div>'
            . '<div class="value">%s</div></div>',
            __('Price per item', 'ohbe'),
            OHBE_Tools::formatPrice($item['price'])
        );
        echo $html;
    }

    /**
     * Render selected accommodation cards.
     *
     * @return string Item's html structure.
     */
    public static function renderSelectedAccos() {
        if (
            isset($_SESSION['ohbe']['selected_accos'])
            && count($_SESSION['ohbe']['selected_accos']) > 0
        ) {
            $acco_cards = '';
            $selected_accos_number = count($_SESSION['ohbe']['selected_accos']);
            $accos_number_text = sprintf(
                _n(
                    '%s accommodation',
                    '%s accommodations',
                    $selected_accos_number,
                    'ohbe'),
                $selected_accos_number
            );
            $total_price = 0;

            foreach ($_SESSION['ohbe']['selected_accos'] as $acco) {
                $total_price += $acco['price'];
                ob_start();
                include(
                    OHBE_PATH . 'includes/templates/views/'
                    . 'accommodation_reservation_card.php'
                );
                $acco_cards .= ob_get_clean();
            }

            return printf(
                '<div class="ohbe-accordion accos-selected-list">'
                . '<div class="alert alert-availability">'
                . '<b>%s</b> %s: %s - %s: %s <b>%s</b></div>'
                . '<div class="booking-confirmation-summary">'
                . '<div class=accommodation-booked-list>%s</div></div></div>',
                $accos_number_text,
                __('Arrival', 'ohbe'),
                $_SESSION['ohbe']['selected_accos'][0]['arrival_string'],
                __('Departure', 'ohbe'),
                $_SESSION['ohbe']['selected_accos'][0]['departure_string'],
                OHBE_Tools::formatPrice($total_price),
                $acco_cards
            );
        }
    }
}
